@@ -315,7 +315,7 @@ def reconciled(product):
         yesterday = (dt.today() - timedelta(days=1)).strftime("%Y-%m-%d")
         for customer_name in common_customers:
             fup_history = core.get_history(customer_name, yesterday)
-            if fup_history[0]['status']:
+            if fup_history['status']:
                 fup_success.append(fup_history)
                 fup_success_name.append(customer_name)
             else:
